@@ -29,7 +29,7 @@ sub init_asp_objects
   
   # Get each of this classes' superclasses, and theirs as well, recursively:
   my %c = map { $_ => 1 } (
-    grep { $_->isa('Apache2::ASP::HTTPHandler') } 
+    grep { $_->isa('Apache2::ASP::GlobalASA') } 
     ( $selfclass, @{"$selfclass\::ISA"} )
   );
   map { $c{$_}++ } map {
