@@ -18,7 +18,7 @@ sub upload_start
   $LastPercent = $Upload->{percent_complete} || 0;
   my $uploadID = $s->_args('uploadID');
   $context->session->{"upload$uploadID$_"} = $Upload->{$_}
-    foreach grep { $_ !~ m/data/ } keys(%$Upload);
+    foreach keys(%$Upload);
   $context->session->save;
 }# end upload_start()
 
@@ -43,14 +43,15 @@ sub upload_hook
   # want to save the Session state once per second:
   my $Diff = time() - $LastUpdate;
   my $PercentDiff = $Upload->{percent_complete} - $LastPercent;
-  
-  if( $Diff >= 1 || $PercentDiff >= 5 )
+  if( $Diff >= 2 || $PercentDiff >= 5 )
   {
-    my $uploadID = $s->_args('uploadID') || '';
+    my $uploadID = $s->_args('uploadID');
+#warn "uploadID: '" . $uploadID . "'";
+#warn "SAVING SESSION!: $Diff $Upload->{percent_complete}%";
     # Store everything in the session except for the data 
     # (since that could be too large to serialize quickly):
     $context->session->{"upload$uploadID$_"} = $Upload->{$_}
-      foreach grep { $_ !~ m/data/ } keys(%$Upload);
+      foreach grep { $_ ne 'data' } keys(%$Upload);
     $context->session->save;
     $LastUpdate = time();
     $LastPercent = $Upload->{percent_complete};
@@ -82,7 +83,7 @@ Apache2::ASP::UploadHandler - Base class for Handlers that process file uploads
 
 =head1 SYNOPSIS
 
-Don't use this clas. Subclass L<Apache2::ASP::MediaManager> instead.
+Subclass L<Apache2::ASP::MediaManager> instead.
 
 =head1 DESCRIPTION
 
